BaseClient class

Class which fetches post request and handle exceptions

Constructors

BaseClient()

Properties

baseHeader Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
post(String endpoint, [String? json, Map<String, String>? header]) Future
Http client connects to the Shopify account by using the url, query and header provided here.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

timeOutDuration → const int
Time out duration is set to 20 seconds. If the http client can't establish a connection by this time, the connection will be closed and an exception is thrown